@@ -1,13 +1,13 @@
 ''' 
  * All rights Reserved, Designed By HIT-Bioinformatics   
  * @Title:  cuteSV_Description.py
- * @author: tjiang
- * @date: Jan 24th 2022
- * @version V1.0.13
+ * @author: tjiang & sqcao
+ * @date: Sep 12th 2022
+ * @version V2.0.2
 '''
 import argparse
 
-VERSION = '1.0.13'
+VERSION = '2.0.2'
 
 class cuteSVdp(object):
 	'''
@@ -227,6 +227,11 @@ def parseArgs(argv):
 		default = 0.6, 
 		type = float)
 
+	GroupAdvanced.add_argument('--remain_reads_ratio', 
+		help = "The ratio of reads remained in cluster. Set lower when the alignment data have high quality but recommand over 0.5.[%(default)s]", 
+		default = 1.0, 
+		type = float)
+
 	# parser.add_argument('-d', '--max_distance', 
 	# 	help = "Maximum distance to group SV together..[%(default)s]", 
 	# 	default = 1000, type = int)
